@@ -14,11 +14,11 @@ bool gCompletionMenu = false;
 int gCompletionScrollTop = 0;
 int gCompletionCursor = -1;
 
-VALUE gPrograms;             // vO⊮
-VALUE gEnvirons;             // ϐ⊮
+VALUE gPrograms;             // ?v???O???????⊮????
+VALUE gEnvirons;             // ???ϐ??⊮????
 
 ///////////////////////////////////////////////////////////////////////////////
-// 
+// ??????
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_init_after_reading_rc_file()
 {
@@ -54,7 +54,7 @@ void cmdline_init_after_reading_rc_file()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// vO⊮ēǂݍ
+// ?v???O???????⊮???????ēǂݍ???
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_rehash()
 {
@@ -64,7 +64,7 @@ void cmdline_rehash()
     rb_ary_push(gPrograms, rb_str_new2("read"));
     rb_ary_push(gPrograms, rb_str_new2("export"));
 
-    /// $PATHɂt@CSgProgramsɓĂ ///
+    /// $PATH?ɂ????t?@?C?????S??gPrograms?ɓ????Ă??? ///
     char* path = getenv("PATH");
     if(path == NULL) {
         fprintf(stderr, "$PATH is NULL\n");
@@ -167,7 +167,7 @@ void cmdline_rehash()
         closedir(dir);
     }
 
-    /// gProgramsɃGCAX ///    
+    /// gPrograms?ɃG?C???A?X???????? ///    
     const int len = vector_size(gAlias);
     for(int i=0; i<len; i++) {
         sAlias* alias = (sAlias*)vector_item(gAlias, i);
@@ -180,7 +180,7 @@ void cmdline_rehash()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// R}hC⊮NA
+// ?R?}???h???C???⊮?????N???A
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion_clear()
 {
@@ -195,14 +195,14 @@ void cmdline_completion_clear()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// R}hC⊮1
+// ?R?}???h???C???⊮1
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion(VALUE all_candidate, char* editing, bool add_space)
 {
     string_obj* str = (string_obj*) vector_item(gCmdLine, gCLCursor);
     char* cstr = string_c_str(str);
 
-    /// qXg[ҏWȂRs[𖖔ɍ쐬 ///
+    /// ?q?X?g???[???ҏW?????Ȃ??R?s?[?𖖔??ɍ쐬 ///
     if(gCLCursor != vector_size(gCmdLine)-1) {
         cmdline_delete_last_str_if_length_0();
         
@@ -337,14 +337,14 @@ void cmdline_completion(VALUE all_candidate, char* editing, bool add_space)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// R}hC⊮2
+// ?R?}???h???C???⊮2
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion2(VALUE all_candidate, char* editing, bool add_space, int candidate_len)
 {
     string_obj* str = (string_obj*) vector_item(gCmdLine, gCLCursor);
     char* cstr = string_c_str(str);
 
-    /// qXg[ҏWȂRs[𖖔ɍ쐬 ///
+    /// ?q?X?g???[???ҏW?????Ȃ??R?s?[?𖖔??ɍ쐬 ///
     if(gCLCursor != vector_size(gCmdLine)-1) {
         cmdline_delete_last_str_if_length_0();
         
@@ -506,7 +506,7 @@ void cmdline_completion2(VALUE all_candidate, char* editing, bool add_space, int
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// vO̕⊮
+// ?v???O???????̕⊮
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion_program(char* editing_dir, char* editing_file, char* editing, int editing_position)
 {
@@ -518,16 +518,16 @@ void cmdline_completion_program(char* editing_dir, char* editing_file, char* edi
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// t@C̕⊮
+// ?t?@?C?????̕⊮
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion_file(char* editing_dir, char* editing_file, char* editing, int editing_position)
 {
     char editing_dir2[kCmdLineMax];
     strcpy(editing_dir2, editing_dir);
 
-    /// editing_dir݂Ȃ ///
+    /// editing_dir?????݂????Ȃ? ///
     if(strcmp(editing_dir2, "") != 0) {
-        /// ϐn܂Ăꍇ ///
+        /// ???ϐ??????n?܂Ă????ꍇ ///
         if(editing_dir2[0] == '$') {
             char new_editing_dir[kCmdLineMax];
             char env_name[256];
@@ -557,7 +557,7 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             }
         }
 
-        /// `_n܂Ăꍇ ///
+        /// ?`???_?????n?܂Ă????ꍇ ///
         else if(editing_dir2[0] == '~') {
             char new_editing_dir[kCmdLineMax];
 
@@ -591,7 +591,7 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
                         strcat(buf, "/");
                     }
 
-#if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H)
+#if (defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H)) && !defined(__CYGWIN7__)
                     char buf2[PATH_MAX];
                     enum eKanjiCode code = kanji_encode_type(buf);
                     if(gKanjiCodeFileName == kUnknown || code == kAscii || gKanjiCodeFileName == code) {
@@ -676,7 +676,7 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// R}hCp[X
+// ?R?}???h???C?????p?[?X
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* editing_dir, char* editing_file, int& editing_position, VALUE& earray, bool& squote, bool& dquote, bool& last_squote, bool& last_dquote)
 {
@@ -822,7 +822,7 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// R}hCŃ^uꂽ̏
+// ?R?}???h???C???Ń^?u???????ꂽ???̏???
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion_main()
 {
@@ -835,7 +835,7 @@ void cmdline_completion_main()
         gCompletionCursor = 0;
     }
     else {
-        /// R}hCp[X ///
+        /// ?R?}???h???C???p?[?X ///
         int editing_position;
         char cmdname[kAliasMax];
         char editing[kAliasMax];
@@ -857,7 +857,7 @@ void cmdline_completion_main()
         gCompletionLastSqort = last_squote;
         gCompletionLastDqort = last_dquote;
     
-        /// Rubyxɍs ///
+        /// Ruby???x???ɍs?? ///
         rb_funcall(rb_cObject, rb_intern("completion_hook"),7, rb_str_new2(editing), rb_str_new2(editing_dir), rb_str_new2(editing_file), rb_str_new2(editing_before), earray, rb_str_new2(cmdname), INT2NUM(editing_position));
 
 
@@ -866,7 +866,7 @@ void cmdline_completion_main()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// `
+// ?`??
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion_view()
 {
@@ -973,7 +973,7 @@ void cmdline_completion_view()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ͏
+// ???͏???
 ///////////////////////////////////////////////////////////////////////////////
 void cmdline_completion_menu_input(int meta, int key)
 {
@@ -1053,7 +1053,7 @@ void cmdline_completion_menu_input(int meta, int key)
         string_obj* str = (string_obj*) vector_item(gCmdLine, gCLCursor);
         char* cstr = string_c_str(str);
 
-        /// qXg[ҏWȂRs[𖖔ɍ쐬 ///
+        /// ?q?X?g???[???ҏW?????Ȃ??R?s?[?𖖔??ɍ쐬 ///
         if(gCLCursor != vector_size(gCmdLine)-1) {
             cmdline_delete_last_str_if_length_0();
             
@@ -1064,7 +1064,7 @@ void cmdline_completion_menu_input(int meta, int key)
             cstr = string_c_str(str);
         }
 
-        /// ⊮} ///
+        /// ?⊮?????????}?? ///
         string_insert(str, gCursor, tmp);
         gCursor+=strlen(tmp);
 
