@@ -9,20 +9,20 @@ extern "C"
 #include <sys/ioctl.h>
 }
 
-bool cDirWnd::gRemainMarks = true;                  // }[NR}hscǂ
+bool cDirWnd::gRemainMarks = true;                  // ?}?[?N???R?}???h?s?????c?????ǂ???
 
 char* cDirWnd::kSortName[cDirWnd::kSortMax] = {
     "name", "name_rev", "extension", "extension_rev", "size", "size_rev",
     "time", "time_rev", "user", "user_rev", "group", "group_rev", "permission", "permission_rev", "random", "none"
 };
 
-vector_obj* gDirStack;                   // fBNgX^bN sDirInfo̔z
-int gDirScrollTop = 0;                   // fBNgX^bNIʂ̃XN[ʒu
-int gDirCursor = 0;                      // fBNgX^bNIʂ̃J[\ʒu
-bool gSelectDir = false;                        // fBNgX^bNIʂǂ
+vector_obj* gDirStack;                   // ?f?B???N?g???X?^?b?N sDirInfo?̔z??
+int gDirScrollTop = 0;                   // ?f?B???N?g???X?^?b?N?I?????ʂ̃X?N???[???ʒu
+int gDirCursor = 0;                      // ?f?B???N?g???X?^?b?N?I?????ʂ̃J?[?\???ʒu
+bool gSelectDir = false;                        // ?f?B???N?g???X?^?b?N?I?????ʂ??ǂ???
 
 ///////////////////////////////////////////////////////////////////////////////
-// EI
+// ???????E?I????
 ///////////////////////////////////////////////////////////////////////////////
 void cDirWnd::Init()
 {
@@ -38,9 +38,9 @@ void cDirWnd::Final()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// RXgN^EfXgN^
+// ?R???X?g???N?^?E?f?X?g???N?^
 ///////////////////////////////////////////////////////////////////////////////
-cDirWnd::eViewOption cDirWnd::gViewOption = cDirWnd::kAll;      // ʕ\̎
+cDirWnd::eViewOption cDirWnd::gViewOption = cDirWnd::kAll;      // ???ʕ\???̎???
 
 cDirWnd::cDirWnd(char* path, bool active)
 {
@@ -99,7 +99,7 @@ cDirWnd::~cDirWnd()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// vCx[g\bh
+// ?v???C?x?[?g???\?b?h
 ///////////////////////////////////////////////////////////////////////////////
 void cDirWnd::clear_dir_stack()
 {
@@ -114,12 +114,12 @@ void cDirWnd::clear_dir_stack()
 ///////////////////////////////////////////////////////////////////////////////
 int convert_fname(char* src, char* des, int des_size) 
 {
-#if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) 
+#if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) || !defined(__CYGWIN7__)
     if(is_all_ascii(src)) {
         strcpy(des, src);
     }
     else {
-        /// Ro[g ///
+        /// ?R???o?[?g ///
         if(kanji_convert(src, des, des_size, gKanjiCodeFileName, gKanjiCode) == -1) {
             return -1;
         }
@@ -132,7 +132,7 @@ int convert_fname(char* src, char* des, int des_size)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// fBXNǂݍ
+// ?f?B?X?N?ǂݍ???
 ///////////////////////////////////////////////////////////////////////////////
 void cDirWnd::read()
 {
@@ -147,7 +147,7 @@ void cDirWnd::read()
     }
     vector_clear(mFiles);
 
-    /// fBXNǂݍ݃tbNH ///
+    /// ?f?B?X?N?ǂݍ??݃t?b?N???????H ///
     VALUE disk_read_ret;
     
     if(gLDir == this)
@@ -155,7 +155,7 @@ void cDirWnd::read()
     else
         disk_read_ret = rb_funcall(rb_cObject, rb_intern("disk_read_hook_rdir"), 0);
     
-    /// tbNȂftHg̃t@Cǂݍ ///
+    /// ?t?b?N???????Ȃ??f?t?H???g?̃t?@?C???ǂݍ??? ///
     if(disk_read_ret == Qnil) {
         DIR* dir = opendir(mPath);
         if(dir == NULL) {
@@ -230,14 +230,14 @@ void cDirWnd::read()
         closedir(dir);
     }
 
-    /// }XN ///
+    /// ?}?X?N ///
     VALUE ret;
     if(this == gLDir)
         ret = rb_funcall(rb_cObject, rb_intern("mask_hook_ldir"), 5, Qnil, INT2NUM(0), INT2NUM(0), INT2NUM(0), INT2NUM(0));
     else
         ret = rb_funcall(rb_cObject, rb_intern("mask_hook_rdir"), 5, Qnil, INT2NUM(0), INT2NUM(0), INT2NUM(0), INT2NUM(0));
     
-    /// }XNtbNȂ߂lfalsẽt@C̓Xg폜 ///
+    /// ?}?X?N?t?b?N???????Ȃ??߂??lfalse?̃t?@?C???̓??X?g?????폜 ///
     if(ret != Qnil) {
         for(int i=0; i<vector_size(mFiles); i++) {
             sFile* file = (sFile*)vector_item(mFiles, i);
@@ -267,7 +267,7 @@ void cDirWnd::read()
         }
     }
     
-    /// I ///
+    /// ?I?? ///
     strcpy(mPathBefore, mPath);
     
     hash_file_num_reset();
@@ -282,7 +282,7 @@ void cDirWnd::DeleteFileFromFileList(int num)
 
 void cDirWnd::AddFile(char* fname) 
 {
-    /// t@Cɑ݂ȂǉȂ ///
+    /// ?????t?@?C?????????ɑ??݂????Ȃ??ǉ??Ȃ? ///
     for(int i=0; i<vector_size(mFiles); i++) {
         sFile* item = (sFile*)vector_item(mFiles, i);
 
@@ -362,7 +362,7 @@ void cDirWnd::AddFile(char* fname)
 
 void cDirWnd::AddFile2(char* fname, char* linkto, int kind, bool user_r, bool user_w, bool user_x, bool group_r, bool group_w, bool group_x, bool other_r, bool other_w, bool other_x, int size, time_t mtime, char* user, char* group)
 {
-    /// t@Cɑ݂ȂǉȂ ///
+    /// ?????t?@?C?????????ɑ??݂????Ȃ??ǉ??Ȃ? ///
     for(int i=0; i<vector_size(mFiles); i++) {
         sFile* item = (sFile*)vector_item(mFiles, i);
 
@@ -460,7 +460,7 @@ void cDirWnd::Activate(cDirWnd* current)
     chdir(mPath);
     setenv("PWD", mPath, 1);
    
-    /// [̃^CgɖOt ///
+    /// ?[???̃^?C?g???ɖ??O???t???? ///
     if(gChangeTerminalTitle) {
         char tmp2[PATH_MAX];
         char* home = getenv("HOME");
@@ -609,7 +609,7 @@ bool cDirWnd::Move(char* path)
          if(dir && access(path3, X_OK) == 0) {
              closedir(dir);
 
-             /// ݂̃fBNgۑ ///
+             /// ???݂̃f?B???N?g?????ۑ? ///
              sDirInfo* dinfo = (sDirInfo*)MALLOC(sizeof(sDirInfo));
              strcpy(dinfo->mPath, mPath);
              dinfo->mCursor = mCursor;
@@ -621,10 +621,10 @@ bool cDirWnd::Move(char* path)
                  list_pop_front(mDirStack);
              }
 
-             /// fBNgƂ̃tbN ///
+             /// ?f?B???N?g?????Ƃ??̃t?b?N ///
              rb_funcall(rb_cObject, rb_intern("path_change_hook"), 1, gLDir == this?Qtrue:Qfalse);
 
-             /// ړ ///
+             /// ?ړ? ///
              char* tmp = STRDUP(mPath);
              char* fname = STRDUP(basename(tmp));
              FREE(tmp);
@@ -636,7 +636,7 @@ bool cDirWnd::Move(char* path)
              read();
              Sort();
    
-             /// [̃^CgɖOt ///
+             /// ?[???̃^?C?g???ɖ??O???t???? ///
              if(gChangeTerminalTitle) {
                  char tmp2[PATH_MAX];
                  char* home = getenv("HOME");
@@ -737,7 +737,7 @@ bool cDirWnd::Move(char* path)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ߂
+// ?߂?
 ///////////////////////////////////////////////////////////////////////////////
 void cDirWnd::MoveBack()
 {
@@ -745,10 +745,10 @@ void cDirWnd::MoveBack()
         sDirInfo* dinfo = (sDirInfo*)list_pop_back(mDirStack);
 
         if(access(dinfo->mPath, F_OK) == 0) {
-             /// fBNgƂ̃tbN ///
+             /// ?f?B???N?g?????Ƃ??̃t?b?N ///
              rb_funcall(rb_cObject, rb_intern("path_change_hook"), 1, gLDir == this?Qtrue:Qfalse);
 
-             /// ߂ ///
+             /// ?߂? ///
              strcpy(mPath, dinfo->mPath);
              read();
 
@@ -765,7 +765,7 @@ void cDirWnd::MoveBack()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ёւ
+// ?ёւ?
 ///////////////////////////////////////////////////////////////////////////////
 void cDirWnd::ChangeSort()
 {
@@ -790,7 +790,7 @@ void cDirWnd::ChangeSort()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// }XNύX
+// ?}?X?N?ύX
 ///////////////////////////////////////////////////////////////////////////////
 bool cDirWnd::ChangeMask(char* mask)
 {
