@@ -2,7 +2,7 @@ require 'etc'
 require 'fileutils'
 
 ###############################################################################
-# e|fBNg
+# テンポラリディレクトリ
 ###############################################################################
 
 if !File.exist?("~/.mfiler2")
@@ -13,7 +13,7 @@ end
 ENV['MTEMP'] = ENV['HOME'] + "/.mfiler2"
 
 ###############################################################################
-# {̐ݒ
+# 日本語の設定
 ###############################################################################
 
 # KCODE
@@ -32,7 +32,7 @@ set_iconv_kanji_code_name "utf8", "utf-8"
 set_iconv_kanji_code_name "utf8-mac", "utf-8-mac"
 
 ###############################################################################
-# L[}bv
+# キーマップ
 ###############################################################################
 keymap   KEY_UP,        27,   91,   65,   -1,      -1,     -1, -1,-1,-1,-1
 keymap   KEY_UP,        27,   79,   65,   -1,       -1,    -1, -1,-1,-1,-1
@@ -110,7 +110,7 @@ keymap   KEY_META_DOWN, 27,   79,   49,    59,      51,    66, -1,-1,-1,-1 # scr
 #keymap   KEY_META_DOWN, 27,   79,   66,    -1,      -1,    -1, -1,-1,-1,-1 # iTerm
 
 ###############################################################################
-# tbN
+# フック
 ###############################################################################
 def atexit_hook_default()
     save_filer_stat()
@@ -206,7 +206,7 @@ def cursor_move_hook(i)
 end
 
 ###############################################################################
-# rubyɂĒ` mfiler2 API 
+# rubyによって定義される mfiler2 API 
 ###############################################################################
 def cmdline(cmd, cursor_pos)
     cmdline_c(cmd, cursor_pos, "enter_cursor_down()")
@@ -1348,7 +1348,7 @@ end
 
 
 ###############################################################################
-# ** ǉvO ***
+# ** 追加プログラム ***
 ###############################################################################
 require "mfiler_completion"
 require "mfiler_directory_history"
@@ -1364,7 +1364,7 @@ require "mfiler_sudo"
 require "mfiler_virtual_directory"
 
 ###############################################################################
-# X^[gAbv
+# スタートアップ
 ###############################################################################
 load_filer_stat()
 
@@ -1413,10 +1413,10 @@ def run_emacs(file)
             n += 1
         end
 
-        # ߂emacsN
+        # 初めてemacsを起動した
         if n == job_num() + 1
             shell("%q%s emacs -nw #{file}", "emacs")
-        # Qڈȍ~
+        # ２回目以降
         else
             shell("%Q%s emacsclient -n #{file} >/dev/null &", file)
             forground_job_title('emacs')
@@ -1427,17 +1427,17 @@ end
 
 
 
-### mfiler2ĨtbN ###
+### mfiler2終了時のフック ###
 def atexit_hook()
     return atexit_hook_default()
 end
 
-### C[ṽtbN ###
+### メインループのフック ###
 def mloop_hook()
     return mloop_hook_default()
 end
 
-### t@Cʉ̕`ʂ̃tbN ###
+### ファイラ画面下部の描写のフック ###
 def view_hook_filer()
     function_string = ["MENU", "RENAM", "ATTR", "EDIT", "COPY", "MOVE", "LINK", "DEL", "MKDIR", "NEW", "EXCUT", "CMD"]
 
@@ -1455,17 +1455,17 @@ def view_hook_filer()
         i += 1
     end
 
-    return 1        # ̕Ԃlt@Cʉcɏk
+    return 1        # この返り値分ファイラが面画縦に縮む
 end
 
-### R}hC⊮̃tbN ###
+### コマンドライン補完時のフック ###
 def completion_hook(editing, editing_dir, editing_file, editing_before, earray, cmd, editing_position)
-    $host_names = ["hogehoge.ac.jp", "hogehoge.net"]        # zXg
-    $user_names = ["hoge"]                                  # [U[
+    $host_names = ["hogehoge.ac.jp", "hogehoge.net"]        # ホスト名
+    $user_names = ["hoge"]                                  # ユーザー名
     
-    ### IWĩR}hC⊮ ###
-    if cmd == "myoriginal"                          # R}hmyoriginal
-        if editing.size >= 1 && editing[0]=="-"[0]  # ݕҏWĂ镶̈ꕶڂ-TABꂽ
+    ### オリジナルのコマンドライン補完 ###
+    if cmd == "myoriginal"                          # コマンド名がmyoriginal
+        if editing.size >= 1 && editing[0]=="-"[0]  # 現在編集している文字列の一文字目が-でTABが押された
             array = [
                 ["-a", "my original option1"],
                 ["-b", "my original option2"]
@@ -1479,4 +1479,4 @@ def completion_hook(editing, editing_dir, editing_file, editing_before, earray,
     return completion_hook_default(editing, editing_dir, editing_file, editing_before, earray, cmd, editing_position)
 end
 
-$sisearch_except_dir = ["/media/", "/mnt/"]          # X[p[CN^T[`ŌȂfBNg
+$sisearch_except_dir = ["/media/", "/mnt/"]          # スーパーインクリメンタルサーチで検索しないディレクトリ
