@@ -1,5 +1,5 @@
 /*
- * C[`
+ * ???C?????[?`??
  */
 
 #include "common.h"
@@ -40,36 +40,36 @@ char gHomeDir[PATH_MAX];
 char gTempDir[PATH_MAX];
 
 ///////////////////////////////////////////////////////////////////////////////
-// Ŏgϐ
+// ??Ŏg???ϐ?
 ///////////////////////////////////////////////////////////////////////////////
-const int kKeyMetaFirst = 128;      // MetaL[R[h̍ŏ
-const int kKeyEsc = 27;             // EscL[R[h
+const int kKeyMetaFirst = 128;      // Meta?L?[?R?[?h?̍ŏ?
+const int kKeyEsc = 27;             // Esc?L?[?R?[?h
 
-static char gHostName[256];         // zXg
-static char gUserName[256];         // [U[
+static char gHostName[256];         // ?z?X?g??
+static char gUserName[256];         // ???[?U?[??
 
 ///////////////////////////////////////////////////////////////////////////////
-// Oɂ炷ϐ
+// ?O?ɂ??炷?ϐ?
 ///////////////////////////////////////////////////////////////////////////////
-cDirWnd* gLDir;                         // ̃fBNgIuWFNg
-cDirWnd* gRDir;                         // ẼfBNgIuWFNg
-bool gMainLoop = false;                 // C[v
-hash_obj* gKeyCommand[2][KEY_MAX];      // L[ƃR}h̃}bv[0][L[R[h] metaȂ [1][L[R[h] meta
-char gTrashBoxPath[PATH_MAX];           // ݔ̃fBNgpX
+cDirWnd* gLDir;                         // ???̃f?B???N?g???I?u?W?F?N?g
+cDirWnd* gRDir;                         // ?E?̃f?B???N?g???I?u?W?F?N?g
+bool gMainLoop = false;                 // ???C?????[?v
+hash_obj* gKeyCommand[2][KEY_MAX];      // ?L?[?ƃR?}???h?̃}?b?v[0][?L?[?R?[?h] meta?Ȃ? [1][?L?[?R?[?h] meta
+char gTrashBoxPath[PATH_MAX];           // ???ݔ??̃f?B???N?g???p?X
 
-bool gExtensionICase = true;            // }[Nt@C̊gqʎső啶ʂ邩ǂ
-bool gColor = false;                    // ʂ̕`ʂɃJ[gǂ
-bool gIndividualCursor = true;          // Ẽt@CʂŃJ[\ʒuƗĂ邩ǂ
-bool gCheckDeleteFile = true;           // t@CɊmF邩ǂ
-bool gCheckCopyFile = false;            // t@CɊmF邩ǂ
-bool gCheckExit = true;                 // t@CI鎞ɊmFғ
-bool gGnuScreen = false;                // GNU screenŋNĂ邩ǂ
-bool gAutoRehash = false;               // R}hCI[gnbV
-bool gUnixDomainSocket = true;          // UnixDomainSocketgǂ
-bool gRemainCursor = false;             // J[\ʒuۑ邩ǂ
+bool gExtensionICase = true;            // ?}?[?N?t?@?C???̊g???q?ʎs?ő啶?????????????ʂ??邩?ǂ???
+bool gColor = false;                    // ???ʂ̕`?ʂɃJ???[???g?????ǂ???
+bool gIndividualCursor = true;          // ???E?̃t?@?C?????ʂŃJ?[?\???ʒu???Ɨ????Ă??邩?ǂ???
+bool gCheckDeleteFile = true;           // ?t?@?C?????????Ɋm?F???邩?ǂ???
+bool gCheckCopyFile = false;            // ?t?@?C?????????Ɋm?F???邩?ǂ???
+bool gCheckExit = true;                 // ?t?@?C?????I?????鎞?Ɋm?F?????ғ?
+bool gGnuScreen = false;                // GNU screen???ŋN?????Ă??邩?ǂ???
+bool gAutoRehash = false;               // ?R?}???h???C???I?[?g???n?b?V??
+bool gUnixDomainSocket = true;          // UnixDomainSocket???g?????ǂ???
+bool gRemainCursor = false;             // ?J?[?\???ʒu???ۑ????邩?ǂ???
 bool gExecutiveFileBold = true;
 bool gReadDirHistory = true;
-enum eKanjiCode gKanjiCodeFileName = kUnknown;     // t@C̊R[h kUnknown̏ꍇ͎
+enum eKanjiCode gKanjiCodeFileName = kUnknown;     // ?t?@?C?????̊????R?[?h kUnknown?̏ꍇ?͎???????
 
 bool gBoldExe = true;
 bool gBoldDir = true;
@@ -78,10 +78,10 @@ int gColorDir = kCACyan;
 int gColorExe = kCARed;
 int gColorLink = kCAMagenta;
 
-char* gVersion = "4.0.9b";
+char* gVersion = "4.1.0";
  
-void (*gViewSystem)() = NULL;      // o^`ʊ֐
-void (*gView)() = NULL;  // [U[po^`ʊ֐
+void (*gViewSystem)() = NULL;      // ?o?^?`?ʊ֐?
+void (*gView)() = NULL;  // ???[?U?[?p?o?^?`?ʊ֐?
 
 bool gChangeTerminalTitle = false;
 
@@ -145,7 +145,7 @@ static void finalize_global_vars()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// Ruby EI
+// Ruby ???????E?I??????
 ////////////////////////////////////////////////////////////////////////////////
 static void myruby_init()
 {
@@ -373,7 +373,7 @@ static void myruby_init()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// Ruby nkfɂ銿ϊ
+// Ruby nkf?ɂ??銿???ϊ?
 ////////////////////////////////////////////////////////////////////////////////
 void ruby_nkf(char* input, char* output, enum eKanjiCode code)
 {
@@ -382,7 +382,7 @@ void ruby_nkf(char* input, char* output, enum eKanjiCode code)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// Ruby nkfɂ銿
+// Ruby nkf?ɂ??銿??????
 ////////////////////////////////////////////////////////////////////////////////
 enum eKanjiCode ruby_kconv_guess(char* input)
 {
@@ -398,12 +398,12 @@ enum eKanjiCode ruby_kconv_guess(char* input)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ^CXNvgt@Cǂݍ
+// ?????^?C???X?N???v?g?t?@?C???ǂݍ???
 ///////////////////////////////////////////////////////////////////////////////
 static void read_rc_file()
 {
 #if defined(MYCYGWINCOMPILE)
-    /// main.rbǂݍ ///
+    /// main.rb???ǂݍ??? ///
     char ms_fname[256];
     sprintf(ms_fname, "%s/etc/main.rb", gProgramHome);
 
@@ -415,7 +415,7 @@ static void read_rc_file()
         exit(1);
     }
 
-    /* etc/.mfilerǂݍ */
+    /* etc/.mfiler???ǂݍ??? */
     char rc_fname[PATH_MAX];
     sprintf(rc_fname,"%s/etc/.mfiler", gProgramHome);
     if(access(rc_fname, R_OK) == 0) {
@@ -437,7 +437,7 @@ static void read_rc_file()
         exit(1);
     }
 
-    /* ~/.mfilerǂݍށB ~/.mfiler ȂȂ$PREFIX/etc/.mfilerǂݍ */
+    /* ~/.mfiler???ǂݍ??ށB? ~/.mfiler ???Ȃ??Ȃ?$PREFIX/etc/.mfiler???ǂݍ??? */
     char* home = getenv("HOME");
     if(home == NULL) {
         fprintf(stderr, "$HOME is NULL");
@@ -464,43 +464,43 @@ static void read_rc_file()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// L[{[h͏
+// ?L?[?{?[?h???͏???
 ///////////////////////////////////////////////////////////////////////////////
 static void input(int meta, int key)
 {
-    /// wv ///
+    /// ?w???v ///
     if(gViewHelp) {
         help_input(meta, key);
     }
-    /// fBNgI ///
+    /// ?f?B???N?g???I?? ///
     else if(gSelectDir) {
         ActiveDir()->SelectDirInput(meta, key);
     }
-    /// R}hC ///
+    /// ?R?}???h???C?? ///
     else if(gCmdLineActive) {
-        /// qXg[I ///
+        /// ?q?X?g???[?I?? ///
         if(vector_size(gHCandidate) > 0)
             cmdline_history_input(meta, key);
-        /// ⊮I ///
+        /// ?⊮?????I?? ///
         else if(gCompletionMenu)
             cmdline_completion_menu_input(meta, key);
-        /// ʂ̃R}hC ///
+        /// ???ʂ̃R?}???h???C?? ///
         else
             cmdline_input(meta, key);
     }
-    /// j[I ///
+    /// ???j???[?I?? ///
     else if(gActiveMenu) {
         gActiveMenu->Input(meta, key);
     }
-    /// CN^T[` ///
+    /// ?C???N???????^???T?[?` ///
     else if(gISearch) {
         isearch_input(meta, key);
     }
-    /// GLXv[[CN^T[` ///
+    /// ?G?L?X?v???[???[???C???N???????^???T?[?` ///
     else if(gISearchExplore && IsISearchExploreChar(meta, key)) {
         isearch_explore_input(meta, key);
     }
-    /// GLXv[[CN^T[` ㉺L[ƃXy[XL[ ///
+    /// ?G?L?X?v???[???[???C???N???????^???T?[?` ?㉺?L?[?ƃX?y?[?X?L?[ ///
     else if(gISearchExplore && !IsISearchNULL() 
         && (meta == 0 && key == ' '
             || meta == 1 && (key == 14 || key == 16)
@@ -510,15 +510,15 @@ static void input(int meta, int key)
     {
         isearch_explore_input(meta, key);
     }
-    /// X[p[CN^T[` ///
+    /// ?X?[?p?[?C???N???????^???T?[?` ///
     else if(gSISearch) {
         sisearch_input(meta, key);
     }
-    /// t@C ///
+    /// ?t?@?C?????? ///
     else {
         sFile* cursor = ActiveDir()->CursorFile();
 
-        /// t@C𓾂 ///
+        /// ?t?@?C?????𓾂? ///
         const char* name = cursor->mName;
         char fname[1024];
         
@@ -527,7 +527,7 @@ static void input(int meta, int key)
             strtolower(fname);
         }
 
-        /// gq𓾂 ///
+        /// ?g???q???𓾂? ///
         char extension[256];
 
         char* tmp = extname(cursor->mName);
@@ -537,18 +537,18 @@ static void input(int meta, int key)
         sprintf(extension, ".%s", tmp);
         free(tmp);
     
-        /// }[NȂ炻̏Ԃ𒲂ׂ ///
-        bool is_extension_marked = false;           // gq̃t@C}[N
-        char marked_extension[1024];                // }[N̊gq
-        bool is_directory_marked = false;           // fBNg}[N
-        bool is_executive_file_marked = false;      // st@C}[N
-        bool is_link_marked = false;                // N}[N
+        /// ?}?[?N???Ȃ炻?̏??Ԃ𒲂ׂ? ///
+        bool is_extension_marked = false;           // ?????g???q?̃t?@?C?????}?[?N??
+        char marked_extension[1024];                // ?}?[?N???̊g???q
+        bool is_directory_marked = false;           // ?f?B???N?g?????}?[?N??
+        bool is_executive_file_marked = false;      // ?s?t?@?C?????}?[?N??
+        bool is_link_marked = false;                // ?????N???}?[?N??
 
         if(ActiveDir()->Marking()) {
             char tmp[1024];
             is_extension_marked = ActiveDir()->IsSameExtensionMarked(tmp);
             if(is_extension_marked) {
-                if(gExtensionICase) {   // 啶ʂȂꍇ
+                if(gExtensionICase) {   // ?啶?????????????ʂ??Ȃ??ꍇ
                     strtolower(tmp);
                 }
                 sprintf(marked_extension, ".mark-%s", tmp);
@@ -559,7 +559,7 @@ static void input(int meta, int key)
             is_link_marked = ActiveDir()->IsLinkMarked();
         }
 
-        /// gq̃t@C}[N ///
+        /// ?????g???q?̃t?@?C?????}?[?N?? ///
         if(is_extension_marked
                 && key >= 0 && key < KEY_MAX
                 && hash_item(gKeyCommand[meta][key], marked_extension))
@@ -572,7 +572,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// N}[N ///
+        /// ?????N???}?[?N?? ///
         else if(is_link_marked
                 && key >= 0 && key < KEY_MAX
                 && hash_item(gKeyCommand[meta][key], ".mark-link"))
@@ -585,7 +585,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// fBNg}[N ///
+        /// ?f?B???N?g?????}?[?N?? ///
         else if(is_directory_marked
                 && key >= 0 && key < KEY_MAX
                 && hash_item(gKeyCommand[meta][key], ".mark-dir"))
@@ -598,7 +598,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// st@C}[N ///
+        /// ?s?t?@?C?????}?[?N?? ///
         else if(is_executive_file_marked
                 && key >= 0 && key < KEY_MAX
                 && hash_item(gKeyCommand[meta][key], ".mark-execute"))
@@ -611,7 +611,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// }[N ///
+        /// ?}?[?N?? ///
         else if(ActiveDir()->Marking()
             && key >= 0 && key < KEY_MAX 
             && hash_item(gKeyCommand[meta][key], ".mark"))
@@ -624,7 +624,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// NI ///
+        /// ?????N???I???? ///
         else if(S_ISLNK(cursor->mLStat.st_mode)
             && key >= 0 && key < KEY_MAX 
             && hash_item(gKeyCommand[meta][key], ".link"))
@@ -637,7 +637,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// t@CŎw肳Ăꍇ ///
+        /// ?t?@?C?????Ŏw?肳???Ă????ꍇ ///
         else if(key >= 0 && key < KEY_MAX  
               && hash_item(gKeyCommand[meta][key], fname))
         {
@@ -650,7 +650,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// gqŎw肳Ăꍇ ///
+        /// ?g???q???Ŏw?肳???Ă????ꍇ ///
         else if(key >= 0 && key < KEY_MAX 
                && hash_item(gKeyCommand[meta][key], extension))
         {
@@ -663,7 +663,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// fBNgI ///
+        /// ?f?B???N?g?????I???? ///
         else if(S_ISDIR(cursor->mLStat.st_mode)
             && key >= 0 && key < KEY_MAX 
             && hash_item(gKeyCommand[meta][key], ".dir"))
@@ -676,7 +676,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// st@CI ///
+        /// ?s?t?@?C?????I???? ///
         else if((cursor->mStat.st_mode&S_IXUSR
              || cursor->mStat.st_mode&S_IXGRP || cursor->mStat.st_mode&S_IXOTH)
             && key >= 0 && key < KEY_MAX 
@@ -690,7 +690,7 @@ static void input(int meta, int key)
             ISearchClear();
         }
 
-        /// ̑̃t@C ///
+        /// ???̑??̃t?@?C?? ///
         else if(key >= 0 && key < KEY_MAX 
             && hash_item(gKeyCommand[meta][key], "*")) 
         {
@@ -710,20 +710,20 @@ static void input(int meta, int key)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// `
+// ?`??
 ///////////////////////////////////////////////////////////////////////////////
 
-/// t@Cʓ͎̃R}hC̕` ///
+/// ?t?@?C?????ʓ??͎??̃R?}???h???C?????̕`?? ///
 static void view_cmdline_filer()
 {
-    const int maxx = mgetmaxx();        // ʃTCY
+    const int maxx = mgetmaxx();        // ???ʃT?C?Y
     const int maxy = mgetmaxy();
     
-    /// CN^T[`` ///
+    /// ?C???N???????^???T?[?`?`?? ///
     if(gISearch) {
         isearch_view();
     }
-    /// Ԃ` ///
+    /// ???Ԃ??`?? ///
     else {
         int error;
         VALUE cmdline_prompt = rb_eval_string_protect("cmdline_prompt()", &error);
@@ -734,28 +734,28 @@ static void view_cmdline_filer()
         else 
             mmvprintw(maxy -2, 0, "the Minnu's Filer2 %s %s %s %s@%s ", gVersion, cDirWnd::kSortName[ActiveDir()->mSortKind], gKanjiCodeString[gKanjiCodeFileName], gUserName, gHostName);
 
-        /// [s@\gĂꍇx` ///            
+        /// ???[???s?@?\???g?Ă????ꍇx???`?? ///            
         if((gXterm && !(gXtermNext||gXterm2)) || (!gXterm && (gXtermNext||gXterm2))) mprintw("x ");
 
         if(gISearchExplore) isearch_explore_view();
     }
 
 
-    /// J[\̃t@C̏` ///          
+    /// ?J?[?\?????̃t?@?C???̏??????`?? ///          
     char buf[1024];
     sFile* file = ActiveDir()->CursorFile();
 
     char permission[12];
     strcpy(permission, "----------");
 
-    if(S_ISDIR(file->mLStat.st_mode)) permission[0] = 'd';  // t@C̎
+    if(S_ISDIR(file->mLStat.st_mode)) permission[0] = 'd';  // ?t?@?C???̎???
     if(S_ISCHR(file->mLStat.st_mode)) permission[0] = 'c';
     if(S_ISBLK(file->mLStat.st_mode)) permission[0] = 'b';
     if(S_ISFIFO(file->mLStat.st_mode)) permission[0] = 'p';
     if(S_ISLNK(file->mLStat.st_mode)) permission[0] = 'l';
     if(S_ISSOCK(file->mLStat.st_mode)) permission[0] = 's';
 
-    mode_t smode = file->mLStat.st_mode;        // p[~bV
+    mode_t smode = file->mLStat.st_mode;        // ?p?[?~?b?V????
     if(smode & S_IRUSR) permission[1] = 'r';
     if(smode & S_IWUSR) permission[2] = 'w';
     if(smode & S_IXUSR) permission[3] = 'x';
@@ -776,7 +776,7 @@ static void view_cmdline_filer()
     
     permission[10] = 0;
 
-    time_t t = file->mLStat.st_mtime;                   // 
+    time_t t = file->mLStat.st_mtime;                   // ????
     struct tm* tm_ = (struct tm*)localtime(&t);
     
     char buf2[1024];
@@ -856,78 +856,78 @@ static void view_cmdline_filer()
 
 void view(bool cmdline)
 {
-    /// wv ///
+    /// ?w???v???? ///
     if(gViewHelp) {
         help_view();
     }
 
-    /// j[ ///
+    /// ???j???[???? ///
     else if(gActiveMenu) {
-        /// t@C ///
+        /// ?t?@?C?????? ///
         gLDir->View();
         gRDir->View();
 
-        /// Wu` ///
+        /// ?W???u???`?? ///
         shell_view();
 
-        /// R}hC` ///
+        /// ?R?}???h???C?????`?? ///
         if(cmdline) {
             view_cmdline_filer();
         }
 
-        /// j[` ///
+        /// ???j???[???`?? ///
         gActiveMenu->View();
     }
 
-    /// fBNgI ///
+    /// ?f?B???N?g???I?????? ///
     else if(gSelectDir) {
         ActiveDir()->SelectDirView();
     }
 
-    /// X[p[CN^T[`` ///
+    /// ?X?[?p?[?C???N???????^???T?[?`?`?? ///
     else if(gSISearch) {
         sisearch_view();
     }
 
-    /// R}hC͎ ///
+    /// ?R?}???h???C?????͎? ///
     else if(gCmdLineActive) {
-        /// qXg[I ///
+        /// ?q?X?g???[?I?????? ///
         if(vector_size(gHCandidate))
             cmdline_history_view();
-        /// ⊮I ///
+        /// ?⊮?????I?????? ///
         else if(vector_size(gCCandidate))
             cmdline_completion_view();
-        /// t@C ///
+        /// ?t?@?C?????? ///
         else {
             gLDir->View();
             gRDir->View();
 
-            /// Wu` ///
+            /// ?W???u???`?? ///
             shell_view();
         }
 
-        /// R}hC̕` ///
+        /// ?R?}???h???C???̕`?? ///
         if(cmdline) {
             cmdline_view();
         }
     }
 
-    /// t@C ///
+    /// ?t?@?C?????? ///
     else {
-        /// fBNg̕` ///
+        /// ?f?B???N?g???̕`?? ///
         gLDir->View();
         gRDir->View();
 
-        /// Wu` ///
+        /// ?W???u???`?? ///
         shell_view();
 
-        /// R}hC̕` ///
+        /// ?R?}???h???C???̕`?? ///
         if(cmdline) {
             view_cmdline_filer();
         }
     }
 
-    /// o^`ʊ֐ ///
+    /// ?o?^?`?ʊ֐? ///
     if(gViewSystem) gViewSystem();
     if(gView) {
         gView();
@@ -938,7 +938,7 @@ void view(bool cmdline)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// exitɎs֐
+// exit???Ɏs???????֐?
 ///////////////////////////////////////////////////////////////////////////////
 void atexit_fun()
 {
@@ -948,12 +948,12 @@ void atexit_fun()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// VOi
+// ?V?O?i??????
 ///////////////////////////////////////////////////////////////////////////////
 static void sig_winch(int signal)
 {
     if(gMainLoop) {
-        mclear_immediately();       // ʂ̍ĕ`
+        mclear_immediately();       // ???ʂ̍ĕ`??
         view(true);
         mrefresh();
     }
@@ -1003,7 +1003,7 @@ void set_signal_mfiler2()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// C֐
+// ???C???֐?
 ///////////////////////////////////////////////////////////////////////////////
 int main(int argc, char* argv[])
 {
@@ -1053,18 +1053,18 @@ LOG_BEGIN();
 
     signal(SIGWINCH, SIG_IGN);
 
-    /// W͂Əo͂[ǂmF ///
+    /// ?W?????͂Əo?͂??????[?????ǂ????m?F ///
     if(!isatty(0) || !isatty(1)) {
         fprintf(stderr, "standard input is not a tty\n");
         return 1;
     }
 
-    /// IvV ///
+    /// ?I?v?V???????? ///
     bool refresh = false;
     bool move_dir = false;
     char move_dir_path[PATH_MAX];
     
-    char init_path[PATH_MAX];   // fBNg
+    char init_path[PATH_MAX];   // ?????f?B???N?g??
     strcpy(init_path, "");
 
     bool script = false;
@@ -1107,14 +1107,14 @@ LOG_BEGIN();
     }
 
 #if defined(MYCYGWINCOMPILE)
-    /// t@CЂƂȂAs ///
+    /// ?t?@?C???ЂƂ??????????Ȃ??A???????s ///
     if(argc == 2 && !refresh && !move_dir) {
         script = true;
         strcpy(script_path, argv[1]);
     }
 #endif
 
-    /// IvVŎw肳ĂȂ瓮Ămfiler2ɉʃtbṼbZ[W𑗂  ///
+    /// ?I?v?V?????Ŏw?肳???Ă????Ȃ瓮???Ă???mfiler2?ɉ??ʃ??t???b?V???̃??b?Z?[?W?𑗂?  ///
     if(refresh && gUnixDomainSocket) {
         DIR* dir = opendir(gTempDir);
         if(dir == NULL) {
@@ -1180,7 +1180,7 @@ LOG_BEGIN();
         return 0;
     }
 
-    /// tHOhWuɂȂ܂Ń[v ///
+    /// ?t?H???O?????h?W???u?ɂȂ??܂Ń??[?v ///
     int status;
     pid_t pgrp;
     while((status = tcgetpgrp(0)) >= 0) {
@@ -1190,19 +1190,19 @@ LOG_BEGIN();
         kill(- pgrp, SIGTTIN);
     }
 
-    /// VZbVn߂ăvZXO[v[_[ɂȂ ///
+    /// ?V?????Z?b?V???????n?߂ăv???Z?X?O???[?v???[?_?[?ɂȂ? ///
     setsid();
     pid_t shell_pgrp = getpid();
     setpgid(shell_pgrp, shell_pgrp);
 
-    /// [̐ ///
+    /// ?[???̐????? ///
     tcsetpgrp(0, shell_pgrp);
 
-    /// RubyC^v^ ///
+    /// Ruby?C???^?v???^?????? ///
     myruby_init();
 
 #if defined(MYCYGWINCOMPILE)
-    /// Ŏw肳ꂽXNvgs ///
+    /// ?????Ŏw?肳?ꂽ?X?N???v?g???s ///
     if(script) {
         rb_eval_string("load 'mfiler_dand.rb'");
         rb_funcall(rb_cObject, rb_intern("run_argument_script"), 1, rb_str_new2(script_path));
@@ -1212,7 +1212,7 @@ LOG_BEGIN();
     }
 #endif
     
-    /// W[̏ ///
+    /// ???W???[???̏????? ///
     variable_init();
     command_init();
     cMenu::Init();
@@ -1221,10 +1221,10 @@ LOG_BEGIN();
     cmdline_init();
     sisearch_init();
 
-    /// O[oϐ̏ ///
+    /// ?O???[?o???ϐ??̏????? ///
     initialize_global_vars(init_path);
 
-    /// \Pbg̏ ///
+    /// ?\?P?b?g?̏????? ///
     char soc_name[256];
     int soc;
     if(gUnixDomainSocket) {
@@ -1249,16 +1249,16 @@ LOG_BEGIN();
         }
     }
 
-    /// ^CXNvgs ///
+    /// ?????^?C???X?N???v?g?s ///
     read_rc_file();
 
     cmdline_init_after_reading_rc_file();
     isearch_init_after_reading_rc_file();
 
-    /// locale̐ݒ ///
+    /// locale?̐ݒ? ///
     if(gKanjiCode == kUtf8) setlocale(LC_CTYPE, "ja_JP.UTF-8");
 
-    /// IvVɂ鏉fBNg̎w ///
+    /// ?I?v?V?????ɂ??鏉???f?B???N?g???̎w?? ///
     if(strcmp(init_path, "") != 0) {
         gLDir->Move(init_path);
         gLDir->SetScrollTop(0);
@@ -1272,20 +1272,20 @@ LOG_BEGIN();
     gLDir->Reread();
     gRDir->Reread();
 
-    /// ANeBufBNgݒ ///
+    /// ?A?N?e?B?u?f?B???N?g?????ݒ? ///
     gLDir->Activate(gRDir);
 
-    /// VOiݒ ///
+    /// ?V?O?i?????ݒ? ///
     set_signal_mfiler2();
     
-    /// J[VX̋N ///
+    /// ?J?[?V?X?̋N?? ///
     minitscr();
     mclear_immediately();
 
-    /// atexito^ ///
+    /// atexit?o?^ ///
     atexit(atexit_fun);
     
-    /// C[v ///
+    /// ???C?????[?v ///
     gMainLoop = true;
 
     fd_set mask;
@@ -1296,18 +1296,18 @@ LOG_BEGIN();
     if(gUnixDomainSocket) FD_SET(soc, &mask);
 
     while(gMainLoop) {
-        /// C[vtbN ///
+        /// ???C?????[?v?t?b?N ///
         rb_funcall(rb_cObject, rb_intern("mloop_hook"), 0);
         
-        /// ` ///
+        /// ?`?? ///
         mclear();
         view(true);
         mrefresh();
 
-        /// selectœ͑҂ ///
+        /// select?œ??͑҂? ///
         read_ok = mask;
 
-        if(!mkbuf_exist()) {            // L[{[h̃obt@ȂȂselect
+        if(!mkbuf_exist()) {            // ?L?[?{?[?h?̃o?b?t?@???Ȃ??Ȃ?select
             if(gUnixDomainSocket) {
                 if(vector_size(gJobs) > 0) {
                     struct timeval tv;
@@ -1334,12 +1334,12 @@ LOG_BEGIN();
             }
         }
 
-        /// L[ ///
-        if(FD_ISSET(0, &read_ok) || mkbuf_exist()) {    // L[͂AL[{[h̃obt@Ȃ
-            /// R}hC͒ ///
+        /// ?L?[???? ///
+        if(FD_ISSET(0, &read_ok) || mkbuf_exist()) {    // ?L?[???͂????????A?L?[?{?[?h?̃o?b?t?@???????Ȃ?
+            /// ?R?}???h???C?????͒? ///
             if(gCmdLineActive) {
                 while(1) {
-                    /// ͂̂selectœ͂ ///
+                    /// ???????͂̂???select?œ??͂??? ///
                     struct timeval tv;
                     tv.tv_sec = 0;
                     tv.tv_usec = 0;
@@ -1348,7 +1348,7 @@ LOG_BEGIN();
 
                     select(1, &read_ok, NULL, NULL, &tv);
 
-                    /// L[͒ ///
+                    /// ?L?[???͒? ///
                     if(FD_ISSET(0, &read_ok) || mkbuf_exist()) {
                         int meta;
                         int key = mgetch(&meta);
@@ -1363,19 +1363,19 @@ LOG_BEGIN();
                            input(0, key);
                         }
                     }
-                    /// L[͂I ///
+                    /// ?L?[???͂??I???? ///
                     else {
                         break;
                     }
                 }
             }
 
-            /// ̑ ///
+            /// ???̑? ///
             else {
                 int meta;
                 int key = mgetch_nonblock(&meta);
 
-                /// ESCL[ ///
+                /// ESC?L?[ ///
                 if(key == -1) {
                 }
                 else if(meta) {
@@ -1394,7 +1394,7 @@ LOG_BEGIN();
             }
         }
 
-        /// UNIX Domain\Pbg ///
+        /// UNIX Domain?\?P?b?g???? ///
         else if(gUnixDomainSocket && FD_ISSET(soc, &read_ok)) {
             char buf[PATH_MAX];
             
@@ -1411,27 +1411,27 @@ LOG_BEGIN();
             }
         }
 
-        /// Wu ///
+        /// ?W???u???? ///
         shell_wait_backgroud_job();
     }
 
-    /// J[VXI ///
+    /// ?J?[?V?X?I???? ///
     mmove_immediately(0,0);
     mclear_immediately();
     mendwin();
 
-    /// VOi ///
+    /// ?V?O?i?????? ///
     set_signal_clear();
     
-    /// SẴWukill ///
+    /// ?S?ẴW???u??kill ///
     shell_kill_all_jobs();
     
-    /// ItbN ///
+    /// ?I???t?b?N ///
     rb_funcall(rb_cObject, rb_intern("atexit_hook"), 0);
     ruby_cleanup(0);
     putp(tigetstr("rmkx"));
 
-    /// W[ ///
+    /// ???W???[?????? ///
     cDirWnd::Final();
     cmdline_final();
     command_final();
@@ -1441,10 +1441,10 @@ LOG_BEGIN();
     variable_final();
     sisearch_final();
     
-    /// O[oϐ ///    
+    /// ?O???[?o???ϐ????? ///    
     finalize_global_vars();
 
-    /// \Pbg ///
+    /// ?\?P?b?g???? ///
     if(gUnixDomainSocket) unlink(soc_name);
 
 CHECKML_BEGIN();
