@@ -2,12 +2,33 @@
 #include <time.h>
 #include <unistd.h>
 #include <termios.h>
-#include "mlib/mcurses.h"
-
-static struct termios gTtySave;
+#include <curses.h>
+#include <sys/types.h>
+#include <sys/time.h>
 
 int main(int argc, char* argv[])
 {
+    fd_set mask;
+    fd_set read_ok;
+    int key;
+
+    printf("\nHIT ANY KEY\n");
+
+    initscr();
+
+    FD_ZERO(&mask);
+    FD_SET(0, &mask);
+
+    read_ok = mask;
+    select(1, &read_ok, NULL, NULL, NULL);
+
+    key = getch();
+
+    endwin();
+
+
+/*
+
     int key;
     int meta;
     fd_set mask;
@@ -42,5 +63,7 @@ int main(int argc, char* argv[])
 
     mcurses_final();
  
+*/
     return 0;
 }
+
