@@ -22,26 +22,26 @@
 #include "minato_debug.h"
 
 ///////////////////////////////////////////////////////////////////////////////
-// `
+// ???`
 ///////////////////////////////////////////////////////////////////////////////
-#define TERM_SIZE_MAX 512               // ^[~iTCY̍ől
-#define UTF_CHAR_SIZE_MAX 6                      // UTF̈ꕶő剽oCg
+#define TERM_SIZE_MAX 512               // ?^?[?~?i???T?C?Y?̍ő??l
+#define UTF_CHAR_SIZE_MAX 6                      // UTF?̈ꕶ???ő剽?o?C?g??
 
-static struct termios gTtySave;                     // [̐ݒۑ
+static struct termios gTtySave;                     // ?[???̐ݒ??ۑ?
 
-static char gBuf[TERM_SIZE_MAX][TERM_SIZE_MAX];             // ̉
-static char gBufBfr[TERM_SIZE_MAX][TERM_SIZE_MAX];          // Orefresh̃̉
-static wchar_t gWBuf[TERM_SIZE_MAX][TERM_SIZE_MAX];         // UTF̃̉
-static wchar_t gWBufBfr[TERM_SIZE_MAX][TERM_SIZE_MAX];      // UTF̑Orefresh̃̉
-static int gBufAttr[TERM_SIZE_MAX][TERM_SIZE_MAX];          // ʂ̕񑮐
-static int gBufAttrBfr[TERM_SIZE_MAX][TERM_SIZE_MAX];       // Orefresh̉ʂ̕񑮐
-static int gBufAttrNow = 0;                                 // ݂̕񑮐
+static char gBuf[TERM_SIZE_MAX][TERM_SIZE_MAX];             // ?????????̉???
+static char gBufBfr[TERM_SIZE_MAX][TERM_SIZE_MAX];          // ?O??refresh???̃????????̉???
+static wchar_t gWBuf[TERM_SIZE_MAX][TERM_SIZE_MAX];         // UTF???̃????????̉???
+static wchar_t gWBufBfr[TERM_SIZE_MAX][TERM_SIZE_MAX];      // UTF???̑O??refresh???̃????????̉???
+static int gBufAttr[TERM_SIZE_MAX][TERM_SIZE_MAX];          // ???ʂ̕????񑮐?
+static int gBufAttrBfr[TERM_SIZE_MAX][TERM_SIZE_MAX];       // ?O??refresh???̉??ʂ̕????񑮐?
+static int gBufAttrNow = 0;                                 // ???݂̕????񑮐?
 
-static int gX = 0, gY = 0;                  // ̃J[\
-static int gCurses = 0;                     // cursesNĂ邩ǂ
-int gKeyEscapeWait = 150000;                // EscapeL[̑҂
+static int gX = 0, gY = 0;                  // ?????????̃J?[?\??
+static int gCurses = 0;                     // ????curses???N?????Ă??邩?ǂ???
+int gKeyEscapeWait = 150000;                // Escape?L?[?̑҂?????
 
-/* L[Ɣro镶̑Ή\ */
+/* ?L?[?Ɣr?o?????镶?????̑Ή??\ */
 struct sKeyMap
 {
     int mKey;
@@ -49,19 +49,19 @@ struct sKeyMap
     int mNum;
 };
 
-vector_obj* gKeyMap = NULL;         // L[}bv̓Iz
+vector_obj* gKeyMap = NULL;         // ?L?[?}?b?v?̓??I?z??
 
-char gKanjiCodeName[5][256];        // R[h̖O
+char gKanjiCodeName[5][256];        // ?????R?[?h?̖??O
 
 char* gKanjiCodeString[6] = {
     "eucjp", "sjis", "utf8", "utf8-mac", "ascii", "unknown"
 };
 
 ///////////////////////////////////////////////////////////////////////////////
-// ֐
+// ??֐?
 ///////////////////////////////////////////////////////////////////////////////
 
-// ʏłQJ̕H
+// ???ʏ??łQ?J?????̕??????H
 static int wis_2cols(wchar_t c)
 {
     wchar_t buf[256];
@@ -72,14 +72,14 @@ static int wis_2cols(wchar_t c)
     return wcswidth(buf, 10) == 2;
 }
 
-// J[[
+// ?J???[?[????
 static int mhas_color()
 {
     return tigetstr("setaf") == NULL;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// W[
+// ???W???[????????
 ///////////////////////////////////////////////////////////////////////////////
 void mcurses_init()
 {
@@ -151,7 +151,7 @@ void mcurses_init()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// W[
+// ???W???[??????
 ///////////////////////////////////////////////////////////////////////////////
 void mcurses_final()
 {
@@ -164,7 +164,7 @@ void mcurses_final()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// J[VX
+// ?J?[?V?X??????
 ///////////////////////////////////////////////////////////////////////////////
 void minitscr()
 {
@@ -244,7 +244,7 @@ void minitscr()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// J[VX
+// ?J?[?V?X????
 ///////////////////////////////////////////////////////////////////////////////
 void mendwin()
 {
@@ -262,7 +262,7 @@ void mendwin()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// L[}bvɃL[ǉ
+// ?L?[?}?b?v?ɃL?[???ǉ?
 ///////////////////////////////////////////////////////////////////////////////
 void madd_keymap(int key, char keys[kKeyMapKeysMax])
 {
@@ -283,7 +283,7 @@ void madd_keymap(int key, char keys[kKeyMapKeysMax])
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ʂ
+// ???ʂ???
 ///////////////////////////////////////////////////////////////////////////////
 void mclear()
 {
@@ -293,7 +293,7 @@ void mclear()
     const int maxx = mgetmaxx();
     const int maxy = mgetmaxy();
     
-    /// ʂ̏ ///
+    /// ???ʂ̏? ///
     for(x=0; x<maxx; x++) {
        space[x] = ' ';
     }
@@ -322,20 +322,24 @@ void mclear()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ʂ𒼐ڏ
+// ???ʂ𒼐ڏ?
 ///////////////////////////////////////////////////////////////////////////////
 void mclear_immediately()
 {
-    /// NA ///
+    /// ?????????N???A ///
     mclear();
     mrefresh();
 
-    /// ʂ ///
+    /// ???ʂ??? ///
+#if defined(__CYGWIN7__)
+    printf("%s", tigetstr("clear"));
+#else
     putp(tigetstr("clear"));
+#endif
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ʂs폜
+// ???ʂ????s?폜
 ///////////////////////////////////////////////////////////////////////////////
 void mclear_online(int y)
 {
@@ -369,7 +373,7 @@ void mclear_online(int y)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// J[\ړ
+// ?J?[?\?????ړ?
 ///////////////////////////////////////////////////////////////////////////////
 void mmove(int y, int x)
 {
@@ -378,16 +382,20 @@ void mmove(int y, int x)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ʏ̃J[\ړ
+// ???ʏ??̃J?[?\?????ړ?
 ///////////////////////////////////////////////////////////////////////////////
 void mmove_immediately(int y, int x)
 {
+#if defined(__CYGWIN7__)
+    printf("%s", tparm(tigetstr("cup"), y, x));
+#else
     putp(tparm(tigetstr("cup"), y, x));
+#endif
     fflush(stdout);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// J[\ړăɕ`
+// ?J?[?\?????ړ????ă????????ɕ????????`??
 ///////////////////////////////////////////////////////////////////////////////
 int mmvprintw(int y, int x, char* str, ...)
 {
@@ -452,7 +460,7 @@ int mmvprintw(int y, int x, char* str, ...)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ɕ`
+// ?????????ɕ????????`??
 ///////////////////////////////////////////////////////////////////////////////
 int mprintw(char* str, ...)
 {
@@ -515,7 +523,7 @@ int mprintw(char* str, ...)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ޕ̑ݒ
+// ???????ޕ??????̑??????ݒ?
 ///////////////////////////////////////////////////////////////////////////////
 void mattron(int attrs)
 {
@@ -523,7 +531,7 @@ void mattron(int attrs)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ޕ̑̐ݒ
+// ???????ޕ??????̑????̐ݒ???????
 ///////////////////////////////////////////////////////////////////////////////
 void mattroff()
 {
@@ -531,7 +539,7 @@ void mattroff()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// {bNXɕ`
+// ?{?b?N?X???????ɕ`??
 ///////////////////////////////////////////////////////////////////////////////
 void mbox(int y, int x, int width, int height)
 {
@@ -569,7 +577,7 @@ void mbox(int y, int x, int width, int height)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ̓eʂɔf
+// ?????????̓??e?????ʂɔ??f
 ///////////////////////////////////////////////////////////////////////////////
 void mrefresh()
 {
@@ -593,8 +601,79 @@ void mrefresh()
                             || gBufAttr[y][x+1] != gBufAttrBfr[y][x+1]
                             )))
                 {
+#if defined(__CYGWIN7__)
+                    printf("%s", tparm(tigetstr("cup"), y, x));
+
+                    if(gBufAttr[y][x] & kCAReverse) printf("%s", tigetstr("rev"));
+                    if(gBufAttr[y][x] & kCABold) printf("%s", tigetstr("bold"));
+                    if(gBufAttr[y][x] & kCAUnderline) printf("%s", tigetstr("rmul"));
+                    if(gBufAttr[y][x] & kCABlack) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 0, 0));
+                    }
+                    if(gBufAttr[y][x] & kCARed) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 1, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCAGreen) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 2, 0));
+                    }
+                    if(gBufAttr[y][x] & kCAYellow) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 3, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABlue) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 4, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCAMagenta) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 5, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCACyan) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 6, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCAWhite) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 7, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackBlack) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 0, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackRed) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 1, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackGreen) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 2, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackYellow) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 3, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackBlue) {
+                        p = tigetstr("setab");
+                            if(p) printf("%s", tparm(p, 4, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackMagenta) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 5, 0));
+                    }
+                    if(gBufAttr[y][x] & kCABackCyan) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 6, 0));
+                    }
+                    if(gBufAttr[y][x] & kCABackWhite) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 7, 0));
+                    }        
+#else
                     putp(tparm(tigetstr("cup"), y, x));
-        
+
                     if(gBufAttr[y][x] & kCAReverse) putp(tigetstr("rev"));
                     if(gBufAttr[y][x] & kCABold) putp(tigetstr("bold"));
                     if(gBufAttr[y][x] & kCAUnderline) putp(tigetstr("rmul"));
@@ -662,7 +741,11 @@ void mrefresh()
                         p = tigetstr("setab");
                         if(p) putp(tparm(p, 7, 0));
                     }        
+#endif
 
+#if defined(__CYGWIN__)
+                    putwc(gWBuf[y][x], stdout);
+#endif
 #if defined(__FREEBSD__)
                     putwc(gWBuf[y][x], stdout);
 #endif
@@ -672,8 +755,11 @@ void mrefresh()
                     wcstombs(mbs, wcs, 256);
                     printf("%s", mbs);
 #endif
-                
+#if defined(__CYGWIN7__)
+                    if(gBufAttr[y][x]) printf("%s", tigetstr("sgr0"));
+#else
                     if(gBufAttr[y][x]) putp(tigetstr("sgr0"));
+#endif
                 }
                 
                 if(wis_2cols(gWBuf[y][x])) {
@@ -697,6 +783,93 @@ void mrefresh()
                             || gBufAttr[y][x+1] != gBufAttrBfr[y][x+1]
                             ))))
                 {
+#if defined(__CYGWIN7__)
+                    printf("%s", tparm(tigetstr("cup"), y, x));
+        
+                    if(gBufAttr[y][x] & kCAReverse) printf("%s", tigetstr("rev"));
+                    if(gBufAttr[y][x] & kCABold) printf("%s", tigetstr("bold"));
+                    if(gBufAttr[y][x] & kCAUnderline) printf("%s", tigetstr("rmul"));
+                    if(gBufAttr[y][x] & kCABlack) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 0, 0));
+                    }
+                    if(gBufAttr[y][x] & kCARed) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 1, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCAGreen) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 2, 0));
+                    }
+                    if(gBufAttr[y][x] & kCAYellow) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 3, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABlue) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 4, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCAMagenta) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 5, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCACyan) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 6, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCAWhite) {
+                        p = tigetstr("setaf");
+                        if(p) printf("%s", tparm(p, 7, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackBlack) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 0, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackRed) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 1, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackGreen) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 2, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackYellow) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 3, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackBlue) {
+                        p = tigetstr("setab");
+                            if(p) printf("%s", tparm(p, 4, 0));
+                    }        
+                    if(gBufAttr[y][x] & kCABackMagenta) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 5, 0));
+                    }
+                    if(gBufAttr[y][x] & kCABackCyan) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 6, 0));
+                    }
+                    if(gBufAttr[y][x] & kCABackWhite) {
+                        p = tigetstr("setab");
+                        if(p) printf("%s", tparm(p, 7, 0));
+                    }        
+
+                    if(is_kanji(gBuf[y][x]) && !is_hankaku(gBuf[y][x])) {
+                        putchar(gBuf[y][x]);
+                        putchar(gBuf[y][x+1]);
+                    }
+                    else if(is_kanji(gBuf[y][x]) && is_hankaku(gBuf[y][x])) {
+                        putchar(gBuf[y][x]);
+                        putchar(gBuf[y][x+1]);
+                        putchar(' ');
+                    }
+                    else {       
+                        putchar(gBuf[y][x]);
+                    }
+                
+                    if(gBufAttr[y][x]) printf("%s", tigetstr("sgr0"));
+                }
+#else
                     putp(tparm(tigetstr("cup"), y, x));
         
                     if(gBufAttr[y][x] & kCAReverse) putp(tigetstr("rev"));
@@ -782,6 +955,7 @@ void mrefresh()
                 
                     if(gBufAttr[y][x]) putp(tigetstr("sgr0"));
                 }
+#endif
                 
                 if(is_kanji(gBuf[y][x])) {
                     x++;
@@ -790,7 +964,11 @@ void mrefresh()
         }
     }
     
+#if defined(__CYGWIN7__)
+    printf("%s", tparm(tigetstr("cup"), gY, gX));
+#else
     putp(tparm(tigetstr("cup"), gY, gX));
+#endif
     
     fflush(stdout);
 
@@ -813,7 +991,7 @@ void mrefresh()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// X̉ʂ̃TCY
+// X?????̉??ʂ̃T?C?Y
 ///////////////////////////////////////////////////////////////////////////////
 int mgetmaxx()
 {
@@ -824,7 +1002,7 @@ int mgetmaxx()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// Ỷʂ̃TCY
+// Y?????̉??ʂ̃T?C?Y
 ///////////////////////////////////////////////////////////////////////////////
 int mgetmaxy()
 {
@@ -839,7 +1017,7 @@ int mgetmaxy()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ݃J[VXNĂ邩ǂ
+// ???݃J?[?V?X???N?????Ă??邩?ǂ???
 ///////////////////////////////////////////////////////////////////////////////
 int mis_curses()
 {
@@ -847,7 +1025,7 @@ int mis_curses()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// L[{[h
+// ?L?[?{?[?h????
 ///////////////////////////////////////////////////////////////////////////////
 static int gKeyBuf[1024];
 static int gKeyBufNum = 0;
@@ -1371,7 +1549,7 @@ int mgetch_nonblock(int* meta)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// pꕶڂǂ
+// ???p?????ꕶ???ڂ??ǂ???
 ///////////////////////////////////////////////////////////////////////////////
 enum eKanjiCode gKanjiCode = kEucjp;
 
@@ -1384,7 +1562,7 @@ int is_hankaku(unsigned char c)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ꕶڂǂ
+// ?????ꕶ???ڂ??ǂ???
 ///////////////////////////////////////////////////////////////////////////////
 int is_kanji(unsigned char c)
 {
@@ -1401,7 +1579,7 @@ int is_kanji(unsigned char c)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ̕񂪉ʂŉ
+// ?????̕????񂪉??ʂŉ???????
 ///////////////////////////////////////////////////////////////////////////////
 int str_termlen(char* mbs)
 {
@@ -1442,7 +1620,7 @@ int str_termlen(char* mbs)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// mbsUTFƌƂutfposڂ܂ł̒[ł̕񐔂Ԃ
+// mbs??UTF???????ƌ????Ƃ???utfpos?????ڂ܂ł̒[?????ł̕????񐔂??Ԃ?
 ///////////////////////////////////////////////////////////////////////////////
 int str_termlen2(char* mbs, int utfpos)
 {
@@ -1469,7 +1647,7 @@ int str_termlen2(char* mbs, int utfpos)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ̕񂪉ʂŉ
+// ?????̕????񂪉??ʂŉ???????
 ///////////////////////////////////////////////////////////////////////////////
 int wcs_termlen(wchar_t* wcs)
 {
@@ -1492,7 +1670,7 @@ int wcs_termlen(wchar_t* wcs)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// UTFŉ
+// ?UTF???ŉ???????
 ///////////////////////////////////////////////////////////////////////////////
 int str_utflen(char* mbs)
 {
@@ -1513,7 +1691,7 @@ int str_utflen(char* mbs)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// mbsUTFƌƂposڂ̈ʒuԂ
+// mbs??UTF???????ƌ????Ƃ???pos?????ڂ̈ʒu???Ԃ?
 ///////////////////////////////////////////////////////////////////////////////
 char* str_utfpos2pointer(char* mbs, int pos)
 {
@@ -1544,7 +1722,7 @@ char* str_utfpos2pointer(char* mbs, int pos)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// mbsUTFƌƂpoint̏ꏊ͉ڂԂ
+// mbs??UTF???????ƌ????Ƃ???point?̏ꏊ?͉??????ڂ????Ԃ?
 ///////////////////////////////////////////////////////////////////////////////
 int str_pointer2utfpos(char* mbs, char* point)
 {
@@ -1562,7 +1740,7 @@ int str_pointer2utfpos(char* mbs, char* point)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// mbs[̕(termsize)̂ݎcĎĉĂdest_mbsɕԂ dest_byte: dest_mbs̃TCY
+// mbs?????[?????̕???????(termsize)?̂ݎc???Ďc?????̂Ă?????????dest_mbs?ɕԂ? dest_byte: dest_mbs?̃T?C?Y
 ///////////////////////////////////////////////////////////////////////////////
 void str_cut(char* mbs, int termsize, char* dest_mbs, int dest_byte)
 {
@@ -1594,8 +1772,8 @@ void str_cut(char* mbs, int termsize, char* dest_mbs, int dest_byte)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// mbs[̕(termsize)̂ݎcĎĉĂdest_mbsɕԂ dest_byte: dest_mbs̃TCY
-// ؂̂ĂXy[XŖ߂
+// mbs?????[?????̕???????(termsize)?̂ݎc???Ďc?????̂Ă?????????dest_mbs?ɕԂ? dest_byte: dest_mbs?̃T?C?Y
+// ?؂??̂Ă??????????X?y?[?X?Ŗ??߂?
 ///////////////////////////////////////////////////////////////////////////////
 void str_cut2(char* mbs, int termsize, char* dest_mbs, int dest_byte)
 {
@@ -1652,10 +1830,10 @@ void str_cut2(char* mbs, int termsize, char* dest_mbs, int dest_byte)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// mbs[̕(termsize)̂ݎcĎĉĂdest_mbsɕԂ 
-// dest_byte: dest_mbs̃TCY
-// ؂̂ĂXy[XŖ߂
-// ؂̂Ă͕̂̑O
+// mbs?????[?????̕???????(termsize)?̂ݎc???Ďc?????̂Ă?????????dest_mbs?ɕԂ? 
+// dest_byte: dest_mbs?̃T?C?Y
+// ?؂??̂Ă??????????X?y?[?X?Ŗ??߂?
+// ?؂??̂Ă??͕̂??????̑O????
 ///////////////////////////////////////////////////////////////////////////////
 void str_cut3(char* mbs, int termsize, char* dest_mbs, int dest_byte)
 {
@@ -1707,7 +1885,7 @@ void str_cut3(char* mbs, int termsize, char* dest_mbs, int dest_byte)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// str_cut3eucjp,sjis
+// str_cut3??eucjp,sjis??
 ///////////////////////////////////////////////////////////////////////////////
 void str_cut3_nonutf8(char* mbs, int termsize, char* dest_mbs)
 {
@@ -1756,7 +1934,7 @@ void str_cut3_nonutf8(char* mbs, int termsize, char* dest_mbs)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// L[{[hobt@݂ΐ^Ԃ
+// ?L?[?{?[?h?o?b?t?@?????݂????ΐ^???Ԃ?
 ///////////////////////////////////////////////////////////////////////////////
 int mkbuf_exist() 
 {
@@ -1767,7 +1945,7 @@ int mkbuf_exist()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// ̊̕R[hԂ
+// ?????̕??????̊????R?[?h???Ԃ?
 ///////////////////////////////////////////////////////////////////////////////
 #if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H)
 
@@ -1794,8 +1972,13 @@ enum eKanjiCode kanji_encode_type(char* buf)
         return kAscii;
     }
 
+/*
 #if defined(__CYGWIN__)
     return ruby_kconv_guess(buf);
+#else
+*/
+#if defined(__CYGWIN7__)
+    return kUtf8;
 #else
     str_in = (char*)malloc(len*2);
     str_out = (char*)malloc(len * UTF_CHAR_SIZE_MAX);
@@ -1804,7 +1987,7 @@ enum eKanjiCode kanji_encode_type(char* buf)
     ptr_out = str_out;
     strcpy(str_in, buf);
 
-
+    
     ic = iconv_open(gKanjiCodeName[kUtf8Mac], gKanjiCodeName[kUtf8Mac]);
     if(!(iconv(ic, &ptr_in, &bufsz_in, &ptr_out, &bufsz_out) < 0 || len-bufsz_in < len)) {
         iconv_close(ic);
@@ -1840,10 +2023,11 @@ enum eKanjiCode kanji_encode_type(char* buf)
         }
     }
 #endif
+//#endif
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// GR[h̕ϊBiconṽbp[
+// ?????G???R?[?h?̕ϊ??Biconv?̃??b?p?[
 ///////////////////////////////////////////////////////////////////////////////
 int kanji_convert(char* input_buf, char* output_buf, size_t output_buf_size, enum eKanjiCode input_kanji_encode_type, enum eKanjiCode output_kanji_encode_type)
 {
@@ -1874,11 +2058,12 @@ int kanji_convert(char* input_buf, char* output_buf, size_t output_buf_size, enu
     }
     
     if(input_kanji_encode_type == kUnknown || output_kanji_encode_type == kUnknown) return -1;
-
+/*
 #if defined(__CYGWIN__)
     ruby_nkf(input_buf, output_buf, output_kanji_encode_type);
 
 #else
+*/
     
     ptr_in = input_buf;
     ptr_out = output_buf;
@@ -1894,13 +2079,13 @@ int kanji_convert(char* input_buf, char* output_buf, size_t output_buf_size, enu
     output_buf[output_buf_size - bufsz_out] = 0;
 
     iconv_close(ic);
-#endif
+//#endif
 
     return 0;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// GR[h̕ϊBiconṽbp[
+// ?????G???R?[?h?̕ϊ??Biconv?̃??b?p?[
 ///////////////////////////////////////////////////////////////////////////////
 int kanji_convert2(string_obj* input_buf, string_obj* output_buf, enum eKanjiCode input_kanji_encode_type, enum eKanjiCode output_kanji_encode_type)
 {
