@@ -1,5 +1,5 @@
 /**********************************************************************
-  iso8859_15.c -  Oniguruma (regular expression library)
+  iso8859_13.c -  Oniguruma (regular expression library)
 **********************************************************************/
 /*-
  * Copyright (c) 2002-2006  K.Kosako  <sndgk393 AT ybb DOT ne DOT jp>
@@ -29,11 +29,11 @@
 
 #include "regenc.h"
 
-#define ENC_ISO_8859_15_TO_LOWER_CASE(c) EncISO_8859_15_ToLowerCaseTable[c]
-#define ENC_IS_ISO_8859_15_CTYPE(code,ctype) \
-  ((EncISO_8859_15_CtypeTable[code] & ctype) != 0)
+#define ENC_ISO_8859_13_TO_LOWER_CASE(c) EncISO_8859_13_ToLowerCaseTable[c]
+#define ENC_IS_ISO_8859_13_CTYPE(code,ctype) \
+  ((EncISO_8859_13_CtypeTable[code] & ctype) != 0)
 
-static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
+static const UChar EncISO_8859_13_ToLowerCaseTable[256] = {
   '\000', '\001', '\002', '\003', '\004', '\005', '\006', '\007',
   '\010', '\011', '\012', '\013', '\014', '\015', '\016', '\017',
   '\020', '\021', '\022', '\023', '\024', '\025', '\026', '\027',
@@ -54,10 +54,10 @@ static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
   '\210', '\211', '\212', '\213', '\214', '\215', '\216', '\217',
   '\220', '\221', '\222', '\223', '\224', '\225', '\226', '\227',
   '\230', '\231', '\232', '\233', '\234', '\235', '\236', '\237',
-  '\240', '\241', '\242', '\243', '\244', '\245', '\250', '\247',
-  '\250', '\251', '\252', '\253', '\254', '\255', '\256', '\257',
-  '\260', '\261', '\262', '\263', '\270', '\265', '\266', '\267',
-  '\270', '\271', '\272', '\273', '\275', '\275', '\377', '\277',
+  '\240', '\241', '\242', '\243', '\244', '\245', '\246', '\247',
+  '\270', '\251', '\272', '\253', '\254', '\255', '\256', '\277',
+  '\260', '\261', '\262', '\263', '\264', '\265', '\266', '\267',
+  '\270', '\271', '\272', '\273', '\274', '\275', '\276', '\277',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
   '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\327',
@@ -68,7 +68,7 @@ static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
   '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\377'
 };
 
-static const unsigned short EncISO_8859_15_CtypeTable[256] = {
+static const unsigned short EncISO_8859_13_CtypeTable[256] = {
   0x2008, 0x2008, 0x2008, 0x2008, 0x2008, 0x2008, 0x2008, 0x2008,
   0x2008, 0x220c, 0x2209, 0x2208, 0x2208, 0x2208, 0x2008, 0x2008,
   0x2008, 0x2008, 0x2008, 0x2008, 0x2008, 0x2008, 0x2008, 0x2008,
@@ -89,10 +89,10 @@ static const unsigned short EncISO_8859_15_CtypeTable[256] = {
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
-  0x0284, 0x01a0, 0x00a0, 0x00a0, 0x00a0, 0x00a0, 0x14a2, 0x00a0,
-  0x10e2, 0x00a0, 0x10e2, 0x01a0, 0x00a0, 0x01a0, 0x00a0, 0x00a0,
-  0x00a0, 0x00a0, 0x10a0, 0x10a0, 0x14a2, 0x10e2, 0x00a0, 0x01a0,
-  0x10e2, 0x10a0, 0x10e2, 0x01a0, 0x14a2, 0x10e2, 0x14a2, 0x01a0,
+  0x0284, 0x01a0, 0x00a0, 0x00a0, 0x00a0, 0x01a0, 0x00a0, 0x00a0,
+  0x14a2, 0x00a0, 0x14a2, 0x01a0, 0x00a0, 0x01a0, 0x00a0, 0x14a2,
+  0x00a0, 0x00a0, 0x10a0, 0x10a0, 0x01a0, 0x10e2, 0x00a0, 0x01a0,
+  0x10e2, 0x10a0, 0x10e2, 0x01a0, 0x10a0, 0x10a0, 0x10a0, 0x10e2,
   0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2,
   0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2,
   0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x14a2, 0x00a0,
@@ -100,11 +100,11 @@ static const unsigned short EncISO_8859_15_CtypeTable[256] = {
   0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2,
   0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2,
   0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x00a0,
-  0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2
+  0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x10e2, 0x01a0
 };
 
 static int
-iso_8859_15_mbc_to_normalize(OnigAmbigType flag,
+iso_8859_13_mbc_to_normalize(OnigAmbigType flag,
 			     const UChar** pp, const UChar* end, UChar* lower)
 {
   const UChar* p = *pp;
@@ -113,7 +113,7 @@ iso_8859_15_mbc_to_normalize(OnigAmbigType flag,
        ONIGENC_IS_MBC_ASCII(p)) ||
       ((flag & ONIGENC_AMBIGUOUS_MATCH_NONASCII_CASE) != 0 &&
        !ONIGENC_IS_MBC_ASCII(p))) {
-    *lower = ENC_ISO_8859_15_TO_LOWER_CASE(*p);
+    *lower = ENC_ISO_8859_13_TO_LOWER_CASE(*p);
   }
   else {
     *lower = *p;
@@ -123,7 +123,7 @@ iso_8859_15_mbc_to_normalize(OnigAmbigType flag,
 }
 
 static int
-iso_8859_15_is_mbc_ambiguous(OnigAmbigType flag,
+iso_8859_13_is_mbc_ambiguous(OnigAmbigType flag,
 			     const UChar** pp, const UChar* end)
 {
   const UChar* p = *pp;
@@ -133,12 +133,12 @@ iso_8859_15_is_mbc_ambiguous(OnigAmbigType flag,
        ONIGENC_IS_MBC_ASCII(p)) ||
       ((flag & ONIGENC_AMBIGUOUS_MATCH_NONASCII_CASE) != 0 &&
        !ONIGENC_IS_MBC_ASCII(p))) {
-    int v = (EncISO_8859_15_CtypeTable[*p] &
+    int v = (EncISO_8859_13_CtypeTable[*p] &
              (ONIGENC_CTYPE_UPPER | ONIGENC_CTYPE_LOWER));
 
     if ((v | ONIGENC_CTYPE_LOWER) != 0) {
-      /* 0xdf etc.. are lower case letter, but can't convert. */
-      if (*p == 0xdf || *p == 0xaa || *p == 0xb5 || *p == 0xba)
+      /* 0xdf, 0xb5 are lower case letter, but can't convert. */
+      if (*p == 0xdf || *p == 0xb5)
         return FALSE;
       else
         return TRUE;
@@ -150,28 +150,19 @@ iso_8859_15_is_mbc_ambiguous(OnigAmbigType flag,
 }
 
 static int
-iso_8859_15_is_code_ctype(OnigCodePoint code, unsigned int ctype)
+iso_8859_13_is_code_ctype(OnigCodePoint code, unsigned int ctype)
 {
   if (code < 256)
-    return ENC_IS_ISO_8859_15_CTYPE(code, ctype);
+    return ENC_IS_ISO_8859_13_CTYPE(code, ctype);
   else
     return FALSE;
 }
 
 static int
-iso_8859_15_get_all_pair_ambig_codes(OnigAmbigType flag,
+iso_8859_13_get_all_pair_ambig_codes(OnigAmbigType flag,
                                      const OnigPairAmbigCodes** ccs)
 {
   static const OnigPairAmbigCodes cc[] = {
-    { 0xa6, 0xa8 },
-    { 0xa8, 0xa6 },
-
-    { 0xb4, 0xb8 },
-    { 0xb8, 0xb4 },
-    { 0xbc, 0xbd },
-    { 0xbd, 0xbc },
-    { 0xbe, 0xff },
-
     { 0xc0, 0xe0 },
     { 0xc1, 0xe1 },
     { 0xc2, 0xe2 },
@@ -234,8 +225,7 @@ iso_8859_15_get_all_pair_ambig_codes(OnigAmbigType flag,
     { 0xfb, 0xdb },
     { 0xfc, 0xdc },
     { 0xfd, 0xdd },
-    { 0xfe, 0xde },
-    { 0xff, 0xbe }
+    { 0xfe, 0xde }
   };
 
   if (flag == ONIGENC_AMBIGUOUS_MATCH_ASCII_CASE) {
@@ -250,9 +240,9 @@ iso_8859_15_get_all_pair_ambig_codes(OnigAmbigType flag,
     return 0;
 }
 
-OnigEncodingType OnigEncodingISO_8859_15 = {
+OnigEncodingType OnigEncodingISO_8859_13 = {
   onigenc_single_byte_mbc_enc_len,
-  "ISO-8859-15",  /* name */
+  "ISO-8859-13",  /* name */
   1,             /* max enc length */
   1,             /* min enc length */
   (ONIGENC_AMBIGUOUS_MATCH_ASCII_CASE |
@@ -269,11 +259,11 @@ OnigEncodingType OnigEncodingISO_8859_15 = {
   onigenc_single_byte_mbc_to_code,
   onigenc_single_byte_code_to_mbclen,
   onigenc_single_byte_code_to_mbc,
-  iso_8859_15_mbc_to_normalize,
-  iso_8859_15_is_mbc_ambiguous,
-  iso_8859_15_get_all_pair_ambig_codes,
+  iso_8859_13_mbc_to_normalize,
+  iso_8859_13_is_mbc_ambiguous,
+  iso_8859_13_get_all_pair_ambig_codes,
   onigenc_ess_tsett_get_all_comp_ambig_codes,
-  iso_8859_15_is_code_ctype,
+  iso_8859_13_is_code_ctype,
   onigenc_not_support_get_ctype_code_range,
   onigenc_single_byte_left_adjust_char_head,
   onigenc_always_true_is_allowed_reverse_match
