@@ -4,7 +4,7 @@
   oniguruma.h - Oniguruma (regular expression library)
 **********************************************************************/
 /*-
- * Copyright (c) 2002-2006  K.Kosako  <sndgk393 AT ybb DOT ne DOT jp>
+ * Copyright (c) 2002-2007  K.Kosako  <sndgk393 AT ybb DOT ne DOT jp>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@ extern "C" {
 
 #define ONIGURUMA
 #define ONIGURUMA_VERSION_MAJOR   4
-#define ONIGURUMA_VERSION_MINOR   4
+#define ONIGURUMA_VERSION_MINOR   6
 #define ONIGURUMA_VERSION_TEENY   1
 
 #ifdef __cplusplus
@@ -47,6 +47,13 @@ extern "C" {
 # endif
 #endif
 
+/* escape Mac OS X/Xcode 2.4/gcc 4.0.1 problem */
+#if defined(__APPLE__) && defined(__GNUC__) && __GNUC__ >= 4
+# ifndef  HAVE_STDARG_PROTOTYPES
+#  define HAVE_STDARG_PROTOTYPES 1
+# endif
+#endif
+
 #ifndef P_
 #if defined(__STDC__) || defined(_WIN32)
 # define P_(args) args
@@ -97,17 +104,11 @@ ONIG_EXTERN OnigAmbigType OnigDefaultAmbigFlag;
 #define ONIGENC_AMBIGUOUS_MATCH_NONE                   0
 #define ONIGENC_AMBIGUOUS_MATCH_ASCII_CASE            (1<<0)
 #define ONIGENC_AMBIGUOUS_MATCH_NONASCII_CASE         (1<<1)
-/* #define ONIGENC_AMBIGUOUS_MATCH_ACCENT             (1<<2) */
-/* #define ONIGENC_AMBIGUOUS_MATCH_HIRAGANA_KATAKANA  (1<<3) */
-/* #define ONIGENC_AMBIGUOUS_MATCH_KATAKANA_WIDTH     (1<<4) */
 
 #define ONIGENC_AMBIGUOUS_MATCH_LIMIT                 (1<<1)
-#define ONIGENC_AMBIGUOUS_MATCH_COMPOUND              (1<<30)
 
 #define ONIGENC_AMBIGUOUS_MATCH_FULL \
-  ( ONIGENC_AMBIGUOUS_MATCH_ASCII_CASE | \
-    ONIGENC_AMBIGUOUS_MATCH_NONASCII_CASE | \
-    ONIGENC_AMBIGUOUS_MATCH_COMPOUND )
+ ( ONIGENC_AMBIGUOUS_MATCH_ASCII_CASE | ONIGENC_AMBIGUOUS_MATCH_NONASCII_CASE )
 #define ONIGENC_AMBIGUOUS_MATCH_DEFAULT  OnigDefaultAmbigFlag
 
 
@@ -708,6 +709,7 @@ struct re_registers {
 typedef struct re_registers   OnigRegion;
 
 typedef struct {
+  OnigEncoding enc;
   OnigUChar* par;
   OnigUChar* par_end;
 } OnigErrorInfo;
