@@ -139,7 +139,6 @@ x(/bc/, 'abc', 1, 3)
 x(/(?i:#RET#)/, '#INS##RET#', 5, 10)
 x(/\17/, "\017", 0, 1)
 x(/\x1f/, "\x1f", 0, 1)
-x(/\xED\xF2/, "\xed\xf2", 0, 2)
 x(/a(?#....\\JJJJ)b/, 'ab', 0, 2)
 x(Regexp.new("(?x)\ta .\n+b"), '0a123b4', 1, 6)
 x(/(?x)  G (o O(?-x)oO) g L/, "GoOoOgLe", 0, 7)
@@ -555,13 +554,14 @@ r(/(((.a)))\3/, 'zazaaa', 0)
 r(/(ac*?z)\1/, 'aacczacczacz', 1)
 r(/aaz{3,4}/, 'bbaabbaazzzaazz', 6)
 r(/\000a/, "b\000a", 1)
-r(/ff\xfe/, "fff\xfe", 1)
+r(/ff\xfe\x00/, "fff\xfe\x00", 1)
 r(/...abcdefghijklmnopqrstuvwxyz/, 'zzzzzabcdefghijklmnopqrstuvwxyz', 2)
 end
 
 def test_euc(enc)
 $KCODE = enc
 
+x(/\xED\xF2/, "\xed\xf2", 0, 2)
 x(//, '', 0, 0)
 x(//, '', 0, 2)
 n(//, '')
